@@ -118,6 +118,19 @@ class Video(DeeplabelBase):
         # fetch again so that the videoUrl is set
         # return cls.from_video_id(video_id, client)
         return video_id
+    
+    @classmethod
+    def update(
+        cls,
+        video_id: str,
+        data: Dict[str, Any],
+        client: "deeplabel.client.BaseClient",
+    ):
+        """Update a video and return the videoId"""
+        data['videoId'] = video_id
+        resp = client.put("/videos",data)
+        video_id = resp.json()["data"]["videoId"]
+        return video_id
 
     @classmethod
     def from_video_id(
